


/* Internetové rádio AURUINO MEGA ( nebo kompatibilní ) s VS 1053B Shield ( nebo kompatibilní ) a Ethernet Shield W5100 R3
*  IR přijímací LED VS 1838B
*  
* Autor :  David Kohout 2 / 2020
*
*/

//   Standartní knihovny
#include <VS1053.h>             // Standartní knihovna VS1053  ( Funguje i pod naším Shieldem, originál knihovnu SFEMP3Shield nepožívat,                        
#include <Ethernet.h>           // Standartní knihovna Ethernet - Shield W5100
#include <IRremote.h>           // Knihovna IR Receive pro Arduino - http://z3t0.github.io/Arduino-IRremote/
#include <LiquidCrystal_I2C.h>  // Knihovna pro I2C LCD displej

const int RECV_PIN = 5;         // IR přijímací dioda připojena na pin 5 Arduina
IRrecv ovladac(RECV_PIN);       // IRrecv jako ovladac, připojený na pin viz výše
decode_results results;         // Přijatá data uložit jako results


// SPI porty ARDUINA MEGA

// 50 - MISO           Při použití ARDUINO MEGA proklemovat 50 Arduino na 12 pin zvukovky
// 51 - MOSI           Při použití ARDUINO MEGA proklemovat 51 Arduino na 11 pin zvukovky
// 52 - SCK            Při použití ARDUINO MEGA proklemovat 52 Arduino na 13 pin zvukovky

// ---------  Nemusí se ohýbat nožičky ze Shieldu, prostě natvrdo dát klemu -----------

VS1053 MP3player(6,7,2,8);  // X_CS 6 pin, X_DCS 7 pin, DREQ 2 pin, X_RESET 8 pin

byte mac[] = {0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED}; // Přiřazení MAC adresy síťovce - možno změnit

EthernetClient client;  // Ethernet jako klient

LiquidCrystal_I2C lcd(0x27, 20, 4); // LCD na adrese 0x27, 20 znaků, 4 řádky


//--------------------------------------------------------------------------------------------------------//

//--------------------------------------------------------------------------------------------------------//
uint8_t mp3buff[32];       // Velikost bufferu 32 Byte
const char *host;          // Zde se uloží adresa serveru s požadovaným streamem
const char *path;          // Zde se uloží cesta serveru s požadovaným streamem
int httpPort;              // Zde se uloží port serveru s požadovaným streamem
int ID_stanice=23;         // Zde se uloží číslo aktuálně přehrávané stanice - konstanta číslo stanice, které začne hrát po spuštění Arduina ( 27=Star*Sat Radio)
int pamet_ID_stanice;      // Zde se uloží číslo posledně přehrávané stanice
String nazev="";           // Zde se uloží jméno aktuálně přehrávané stanice
String zanr="";            // Zde se uloží žánr aktuálně přehrávané stanice
int Li          = 20;      // Poslední znak na řádku - pozice
int Lii         = 0;       // První znak na řádku - pozice
int Delka_textu = 0;       // Délka srolovacího textu na LCD - 0 = inicializační
int Prodleva=0;            // Prodleva před posunutím znaku na LCD
int Volume=30;             // Výchozí hlasitost rádia po zapnutí

void setup() {

 ovladac.enableIRIn();         // Start IR přijímací diody
 ovladac.blink13(false);       // Frekvence snímkování IR - U MEGA FALSE !
 Ethernet.begin(mac);          // Start Ethernetového spojení, IP adresu přiřadí router
 MP3player.begin();            // Start zvukové karty VS1053B Shield
 MP3player.setVolume(Volume);  // Nižší číslo vyšší hlasitost
 lcd.init();                   // Inicializace LCD displeje
 lcd.backlight();              // Podsvícení LCD displeje


    
    client.print(String("GET ") + path + " HTTP/1.1\r\n" +                    // Adresa serveru se streamem - požadavek při spuštění Arduina
                  "Host: " + host + "\r\n" + 
                  "Connection: close\r\n\r\n");

             
}



void loop() {                          // Hlavní program - smyčka

if (ovladac.decode(&results)){         // Pokud IR dioda přijme nějaká data, tak hledej níže
 
        switch(results.value){         // Nějaká přijatá data z IR...
          
          case 0xFFA25D:               // Pokud je to kód 0xFFA25D,   CH -
          if (ID_stanice >1) {         // a je-li aktuální stanice větší jak 1,
          ID_stanice=ID_stanice -1;    // tak odečti číslo 1 od aktuální stanice
          }
          break;
   
          case 0xFFE21D:               // Pokud je to kód 0xFFE21D,   CH +
          if (ID_stanice <150) {        // a je-li aktuální stanice menší jak 13,
          ID_stanice=ID_stanice +1;    // tak přičti číslo 1 k aktuální stanici
          }
          break;

          case 0xFF22DD:                // Pokud je to kód 0xFF22DD,    <<
          if (ID_stanice >11) {         // a je-li aktuální stanice větší jak 11,
          ID_stanice=ID_stanice -10;    // tak odečti číslo 10 od aktuální stanice
          }
          break;
   
          case 0xFF02FD:                // Pokud je to kód 0xFF02FD,   >>
          if (ID_stanice <140) {        // a je-li aktuální stanice menší jak 140,
          ID_stanice=ID_stanice +10;     // tak přičti číslo 10 k aktuální stanici
          }
          break;

          case 0xFFE01F:               // Pokud je to kód 0xFFE01F,  VOLUME -
          if (Volume <96){             // a je-li aktuální hlasitost menší jak 95,
            Volume=Volume +3;          // tak připočti čislo 5 ( vyšší číslo menší hlasitost )
         MP3player.setVolume(Volume);  // Vyšší číslo menší hlasitost
            }
          break;

           case 0xFFA857:              // Pokud je to kód 0xFFA857,  VOLUME +
          if (Volume >3){              // a je-li aktuální hlasitost větší jak 5,
            Volume=Volume -3;          // tak odeči číslo 5 ( menší číslo vyšší hlasitost )
         MP3player.setVolume(Volume);  // Nižší číslo větší hlasitost
            }  
          break;

           case 0xFF6897:              // Klávesa 0 - Předvolba 0 - STAR*SAT RADIO
       ID_stanice=27;
           break;

           case 0xFF30CF:              // Klávesa 1 - Předvolba 1 - HITRÁDIO 80 CZ
       ID_stanice=1;
           break;

           case 0xFF18E7:              // Klávesa 2 - Předvolba 2 - RADIO MONACO 89.2
       ID_stanice=35;
           break;

           case 0xFF7A85:              // Klávesa 3 - Předvolba 3 - ANTENNE BAYERN 80-ER
       ID_stanice=23;
           break;

            case 0xFF10EF:             // Klávesa 4 - Předvolba 4 - HITRÁDIO ORION
       ID_stanice=9;
           break;

            case 0xFF38C7:             // Klávesa 5 - Předvolba 5 - GR ATHENS PARTY
       ID_stanice=61;
           break;

            case 0xFF5AA5:             // Klávesa 6 - Předvolba 6 - ANTENNE BAYERN 90-ER
       ID_stanice=150;
           break;

           case 0xFF42BD:              // Klávesa 7 - Předvolba 7 - SK SKY RÁDIO
       ID_stanice=89;
           break;

           case 0xFF4AB5:              // Klávesa 8 - Předvolba 8 - ČRO OLOMOUC
       ID_stanice=100;
           break;

           case 0xFF52AD:              // Klávesa 9 - Předvolba 9 - FR CHÉRIE NO REPEAT
       ID_stanice=51;
           break;
               
        }
        delay(200);                    // Čekej 200 ms,
        ovladac.resume();              // Pak můžeš přijmout další data z IR
  }

//----------------------------------------------------------------------------------------------------  

  Prodleva=Prodleva+1;
                                                                                                                
switch(ID_stanice){              // Přepínání stanic - ID stanice
        case 1:
             nazev = "Hitradio Osmdesatka";       
             host = "ice.abradio.cz";         // Hitrádio 80
             path = "/hit80128.mp3";
             httpPort = 80;
             zanr="  DISKOTEKA 80 LET";
            break;
        case 2:
           nazev = "Hitradio Devadesatka"; 
           host= "ice.abradio.cz";           // Hitrádio 90
           path = "/hit90128.mp3";
           httpPort = 80;
           zanr="  DISKOTEKA 90 LET";
            break;
        case 3:
            nazev = "Radio Rubi"; 
            host = "icecast8.play.cz";       // Radio Rubi
            path = "/radiorubi128.mp3";
            zanr="       TOP 40";
            httpPort = 80;;
            break;
        case 4:
            nazev = "Dance radio"; 
            host = "icecast6.play.cz";       // Dance Radio
            path = "/dance-radio128.mp3";
            zanr="        DANCE";
            httpPort = 80;;
            break;
        case 5:
            nazev = "FUN radio SK";
            host = "stream.funradio.sk";     // Fun rádio SK
            path = "/dance128.mp3";
            zanr="       TOP 40";
            httpPort = 8000;
            break;
        case 6:
            nazev = "Classic 21 90 BE";
            host = "radios.rtbf.be";     // Classic 21 90´ BE
            path = "/wr-c21-90-128.mp3";
            zanr="  DISKOTEKA 90 LET";
            httpPort = 80;
            break;
        case 7:
            nazev = "Hit West 80";
            host = "streamingp.shoutcast.com";  // Hity 80 let
            path = "/HITWEST80.mp3";
            zanr="  DISKOTEKA 80 LET";
            httpPort = 80;
            break;
        case 8:
            nazev = "105 Hits Italy" ;     // 105 Hits Italy
            host = "icy.unitedradio.it";
            path = "/105Hits.mp3?";
            zanr="       TOP 40";
            httpPort = 80;
            break;
        case 9:
            nazev = "Hitradio Orion Morava"; // CZ Hitrádio Orion Morava
            host = "ice.abradio.cz";
            path = "/orionmorava128.mp3";
            zanr="       TOP 40";
            httpPort = 8000;
            break;
        case 10:
            nazev = "Blanik FM";             // CZ Rádio Blaník FM
            host = "ice.abradio.cz";
            path = "/blanikfm128.mp3";
            zanr="   ZABAVA , ZPRAVY";
            httpPort = 80;
            break;
        case 11:
            nazev = "Rock Max Hard";      // CZ Rock Max Hard
            host = "212.111.2.151";
            path = "/rm_hard_128.mp3";
            zanr="       ROCK";
            httpPort =8000;
            break;

         case 12:
            nazev = "Rock Radio - Rockova zabava";      // CZ Rock Radio - Rockova zabava
            host = "ice.abradio.cz";
            path = "/rockzabava128.mp3";
            zanr="       ROCK";
            httpPort =80;
            break;

         case 13:
            nazev = "Radio Cas Rock";      // CZ Rádio Čas Rock
            host = "icecast7.play.cz";
            path = "/casrock128.mp3";
            zanr="        ROCK";
            httpPort =80;
            break;

         case 14:
            nazev = "Evropa 2";      // CZ Evropa 2
            host = "icecast3.play.cz";
            path = "/evropa2-128.mp3?";
            zanr="   ZABAVA , ZPRAVY";
            httpPort =80;
            break;

         case 15:
            nazev = "Evropa 2 Top 40";      // CZ Evropa 2 Top 40
            host = "ice.actve.net";
            path = "/web-e2-top40";
            zanr="       TOP 40";
            httpPort =80;
            break;  

         case 16:
            nazev = "KISS 98 FM";      // CZ Kiss 98 FM
            host = "icecast4.play.cz";
            path = "/kiss128.mp3";
            zanr="   ZABAVA , ZPRAVY";
            httpPort =80;
            break; 

         case 17:
            nazev = "Radio Zlin Best Ballads";      // CZ Rádio Zlín Best Ballads
            host = "212.111.2.151";
            path = "/radiozlin_128.mp3";
            zanr="  POHODOVY POSLECH";
            httpPort =8000;
            break;

         case 18:
            nazev = "Rock radio Metalomanie";      // CZ Rock rádio Metalománie
            host = "ice.abradio.cz";
            path = "/metalomanie128.mp3";
            zanr="       METAL";
            httpPort =80;
            break;

         case 19:
            nazev = "Rock Max";      // CZ Rock Max
            host = "212.111.2.151";
            path = "/rockmax_128.mp3";
            zanr="       ROCK";
            httpPort =8000;
            break;

         case 20:
            nazev = "Charivari Munchen";      // Charivari Munchen
            host = "rs5.stream24.net";
            path = "/stream?ref=charivari.de";
            zanr="        POP";
            httpPort =80;
            break;

         case 21:
            nazev = "Berliner Rundfunk";      // Berliner Rundfunk
            host = "topradio-de-hz-fal-stream06-cluster01.radiohost.de";
            path = "/brf_mp3-128";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 22:
            nazev = "Antenne Bayern - Top 40";      // Antenne Bayern - Top 40
            host = "mp3channels.webradio.antenne.de";
            path = "/top-40";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 23:
            nazev = "Antenne Bayern - 80er Hits";      // Antenne Bayern - 90er Hits
            host = "mp3channels.webradio.antenne.de";
            path = "/80er-kulthits";
            zanr="  DISKOTEKA 80 LET";
            httpPort =80;
            break;

         case 24:
            nazev = "Antenne Bayern - 90er Hits"; 
            host = "mp3channels.webradio.antenne.de";       // Antenne Bayern - 90er Hits 
            path = "/90er-hits";
            zanr="  DISKOTEKA 90 LET";
            httpPort = 80;
            break;

         case 25:
            nazev = "Antenne Bayern - Fresh Hits";      // Antenne Bayern - Fresh Hits
            host = "mp3channels.webradio.antenne.de";
            path = "/fresh";
            zanr="        POP";
            httpPort =80;
            break;

         case 26:
            nazev = "Antenne Bayern - Love Songs";      // Antenne Bayern - Love Songs
            host = "mp3channels.webradio.antenne.de";
            path = "/lovesongs";
            zanr="  POHODOVY POSLECH";
            httpPort =80;
            break;

         case 27:
            nazev = "Star*Sat Radio";      // DE STAR*SAT RADIO
            host = "starsat-ais-edge-3005.fra-eco.cdn.addradio.net";
            path = "/starsat/live/mp3/low/stream.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 28:
            nazev = "Angels Fox Radio"; 
            host = "213.239.219.50";       // Angels Fox Radio DE 
            path = "/afr128.mp3";
            zanr="       RUZNE";
            httpPort = 80;
            break;

         case 29:
            nazev = "N-Joy Radio Bulgaria";      // BG N-Joy Radio
            host = "live.btvradio.bg";
            path = "/njoy.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 30:
            nazev = "Alpha Radio Bulgaria";      // BG Alpha Radio
            host = "alpharadio.bg";
            path = "/stream";
            zanr="        POP";
            httpPort =8000;
            break;

         case 31:
            nazev = "All Zic - Zouk";              // FR All Zic - Zouk
            host = "allzic28.ice.infomaniak.ch";
            path = "/allzic28.mp3";
            zanr="      TROPICAL";
            httpPort =80;
            break;

         case 32:
            nazev = "Kultural Online - Antila";    // Kultural Online - Nizozemské Antily
            host = "38.96.148.37";
            path = "/;stream.mp3";
            zanr="      TROPICAL";
            httpPort =9176;
            break;

         case 33:
            nazev = "Red Hot Flames - Antigua and Barbuda ";    // Karibik
            host = "162.244.80.34";
            path = "/;stream.mp3";
            zanr="      TROPICAL";
            httpPort =6444;
            break;

         case 34:
            nazev = "Radio Monte Carlo 80";    // Monako Radio Monaco 80
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb008";
            zanr="  DISKOTEKA 80 LET";
            httpPort =80;
            break;

       case 35:
            nazev = "Radio Monte Carlo 98.2";    // Monako RMC 98.2
            host = "radiomonaco.ice.infomaniak.ch";
            path = "/radiomonaco-128.mp3";
            zanr="        DANCE";
            httpPort =80;
            break;

         case 36:
            nazev = "Radio Monte Carlo Hits";    // Monako RMC Hits
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb001";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 37:
            nazev = "Radio Monte Carlo Kay Kay";    // Monako RMC Kay Kay
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb004";
            zanr="         POP";
            httpPort =80;
            break;

         case 38:
            nazev = "Radio Monte Carlo Marine";    // Monako RMC Marine
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb015";
            zanr="         POP";
            httpPort =80;
            break;

         case 39:
            nazev = "Radio Monte Carlo Italia";    // Monako RMC Italia
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb005";
            zanr="         POP";
            httpPort =80;
            break;

         case 40:
            nazev = "Radio Monte Carlo Great Artist";    // Monako RMC Great Artist
            host = "edge.radiomontecarlo.net";
            path = "/rmcweb007";
            zanr="         POP";
            httpPort =80;
            break;

         case 41:
            nazev = "Music 100.9 Monaco";    // Monako 100.9
            host = "ice12.fluidstream.net";
            path = "/fluid1203.mp3";
            zanr="         POP";
            httpPort =80;
            break;

         case 42:
            nazev = "Cannes Radio France";    // FR Cannes Radio
            host = "cannesradio.ice.infomaniak.ch";
            path = "/cannesradio-128.mp3";
            zanr="         POP";
            httpPort =80;
            break;

         case 43:
            nazev = "Cerise 88.2 FM France";    // FR Cerise 88.2 FM
            host = "cerisefm.ice.infomaniak.ch";
            path = "/cerisefm-128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 44:
            nazev = "Cherie Ballads FR";    // FR Chérie Ballads
            host = "185.52.127.131";
            path = "/fr/30297/mp3_128.mp3";
            zanr="    BEST BALLADS";
            httpPort =80;
            break;

         case 45:
            nazev = "Cherie Celine Dion FR";    // FR Chérie Celine Dion
            host = "185.52.127.168";
            path = "/fr/55507/mp3_128.mp3";
            zanr="         POP";
            httpPort =80;
            break;

         case 46:
            nazev = "Cherie FM FR";    // FR Chérie FM
            host = "185.52.127.163";
            path = "/fr/30201/mp3_128.mp3";
            zanr="         POP";
            httpPort =80;
            break;

          case 47:
            nazev = "Cherie Frenchy";    // FR Chérie Frenchy
            host = "185.52.127.131";
            path = "/fr/30213/mp3_128.mp3?";
            zanr="         POP";
            httpPort =80;
            break;

         case 48:
            nazev = "Cherie Jazzy";    // FR Chérie Jazzy
            host = "185.52.127.159";
            path = "/fr/30241/mp3_128.mp3?";
            zanr="        JAZZ";
            httpPort =80;
            break;

         case 49:
            nazev = "Cherie Latino";    // FR Chérie Latino
            host = "185.52.127.159";
            path = "/fr/30247/mp3_128.mp3?";
            zanr="       LATINO";
            httpPort =80;
            break;

         case 50:
            nazev = "Cherie Les plus belles voix";    // FR Chérie Les plus belles voix
            host = "185.52.127.131";
            path = "/fr/30317/mp3_128.mp3?";
            zanr="        LOVE";
            httpPort =80;
            break;

         case 51:
            nazev = "Cherie No Repeat";    // FR Chérie No Repeat
            host = "185.52.127.159";
            path = "/fr/30295/mp3_128.mp3?";
            zanr="      POHODOVE";
            httpPort =80;
            break;

         case 52:
            nazev = "Cherie 80s";    // FR Chérie 80s
            host = "185.52.127.159";
            path = "/fr/30237/mp3_128.mp3?";
            zanr="  DISKOTEKA 80 LET";
            httpPort =80;
            break;

         case 53:
            nazev = "Cherie @ Work";    // FR Chérie @ Work
            host = "185.52.127.131";
            path = "/fr/30215/mp3_128.mp3?";
            zanr="         POP";
            httpPort =80;
            break;

         case 54:
            nazev = "Cherie Acoustic";    // FR Chérie Acoustic
            host = "185.52.127.159";
            path = "/fr/30269/mp3_128.mp3?";
            zanr="       OLDIES";
            httpPort =80;
            break;

         case 55:
            nazev = "Cherie Adele";    // FR Chérie Adele
            host = "185.52.127.132";
            path = "/fr/30201/mp3_128.mp3?origine=mytuner";
            zanr="         POP";
            httpPort =80;
            break;

         case 56:
            nazev = "Cherie Pop Love";    // FR Chérie Pop Love
            host = "185.52.127.162";
            path = "/fr/30207/mp3_128.mp3?";
            zanr="      POHODOVE";
            httpPort =80;
            break;

         case 57:
            nazev = "Cherie Romantic";    // FR Chérie Romantic
            host = "185.52.127.172";
            path = "/fr/30287/mp3_128.mp3?";
            zanr="      POHODOVE";
            httpPort =80;
            break;

         case 58:
            nazev = "Cherie Sweet Home";    // FR Chérie Sweet Home
            host = "185.52.127.172";
            path = "/fr/30289/mp3_128.mp3?";
            zanr="      POHODOVE";
            httpPort =80;
            break;

         case 59:
            nazev = "Aktina 104,7 FM Corfu";    // GR Aktina 104,7 FM Corfu
            host = "live.e-streaming.eu";
            path = "/";
            zanr="       TOP 40";
            httpPort =8110;
            break;

         case 60:
            nazev = "Arion Eurovision GR";    // GR Arion Eurovision
            host = "ice.onestreaming.com";
            path = "/arion";
            zanr="       NATIONAL";
            httpPort =80;
            break;

         case 61:
            nazev = "Athens Party GR";    // GR Athens Party
            host = "ice.onestreaming.com";
            path = "/athensparty";
            zanr="     POP , DANCE";
            httpPort =80;
            break;

         case 62:
            nazev = "Chroma Radio GR";    // GR Chroma Radio
            host = "chromaradio.com";
            path = "/";
            zanr="       HITY 80";
            httpPort =8002;
            break;

         case 63:
            nazev = "Fun Radio Top 20";    // SK Fun Radio Top 20
            host = "stream.funradio.sk";
            path = "/fun128.mp3";
            zanr="       TOP 40";
            httpPort =8000;
            break;

            case 64:
            nazev = "Radio Capris Dalmacija";    // SI Radio Capris Dalmacija
            host = "stream02.exit.si";
            path = "/DALMACIJA?";
            zanr="        FOLK";
            httpPort =8000;
            break;

         case 65:
            nazev = "Radio Capris Slovinsko";    // SI Radio Capris Slovinsko
            host = "stream01.exit.si";
            path = "/live?";
            zanr="       NATIONAL";
            httpPort =8000;
            break;

         case 66:
            nazev = "Radio Capris 80s Slovinsko";    // SI Radio Capris 80s Slovinsko
            host = "stream02.exit.si";
            path = "/80?";
            zanr="       HITY 80";
            httpPort =8000;
            break;

         case 67:
            nazev = "Radio Capris 90s Slovinsko";    // SI Radio Capris 90s Slovinsko
            host = "stream02.exit.si";
            path = "/90?";
            zanr="       HITY 90";
            httpPort =8000;
            break;

         case 68:
            nazev = "Naxi - 80s Serbia";    // RS Radio Naxi - 80s Serbia
            host = "naxidigital128.kbcnet.rs";
            path = "/";
            zanr="       HITY 80";
            httpPort =8040;
            break;

         case 69:
            nazev = "Naxi - Caffe Serbia";    // RS Radio Naxi - Caffe Serbia
            host = "naxidigital128.kbcnet.rs";
            path = "/";
            zanr="       OLDIES";
            httpPort =8020;
            break;

         case 70:
            nazev = "Naxi - Clubbing Serbia";    // RS Radio Naxi - Clubbing Serbia
            host = "naxidigital128.kbcnet.rs";
            path = "/";
            zanr="       DANCE";
            httpPort =8090;
            break;

         case 71:
            nazev = "Naxi - Serbian Evergreen";    // RS Radio Naxi - Serbian Evergreen
            host = "naxidigital128.kbcnet.rs";
            path = "/";
            zanr="       NATIONAL";
            httpPort =8010;
            break;

         case 72:
            nazev = "RSG - Relax Serbian ";    // RS Radio RSG - Relax
            host = "stream.rsg.rs";
            path = "/stream";
            zanr="       RELAX";
            httpPort =8063;
            break;

         case 73:
            nazev = "Akous Dreams Greece";    // GR Akous Dreams
            host = "ice.onestreaming.com";
            path = "/akousdreams";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 74:
            nazev = "COTN Radio UK";    // UK COTN Radio
            host = "streaming.smartradio.ch";
            path = "/stream";
            zanr="       RELAX";
            httpPort =8010;
            break;

         case 75:
            nazev = "Europa Plus - Light Russia";    // RU Europa Plus - Light
            host = "emg02.hostingradio.ru";
            path = "/ep-light128.mp3";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 76:
            nazev = "FFH Lounge DE";    // DE FFH Lounge
            host = "mp3.ffh.de";
            path = "/ffhchannels/hqlounge.mp3";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 77:
            nazev = "Frequence Verte";    // FR Fréquence Verte
            host = "listen.radioking.com";
            path = "/radio/209212/stream/252127";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 78:
            nazev = "Gamma Gioiosa Lovesongs";    // IT Gamma Gioiosa Lovesongs
            host = "95.110.186.253";
            path = "/gammalove.mp3";
            zanr="        LOVE";
            httpPort =8000;
            break;

         case 79:
            nazev = "Hitradio RT 1 DE";    // DE Hitradio RT 1 - Relax
            host = "rt1-ais-edge-3001.fra-eco.cdn.addradio.net";
            path = "/rt1/relax/mp3/high/stream.mp3";
            zanr="        LOVE";
            httpPort =80;
            break;

         case 80:
            nazev = "MFM MLady France";    // FR MFM MLady
            host = "mfm.ice.infomaniak.ch";
            path = "/mfm-128.mp3";
            zanr="        LOVE";
            httpPort =80;
            break;

         case 81:
            nazev = "Fun Radio Czechoslovakia";    // SK Fun Radio Czechoslovakia 
            host = "stream.funradio.sk";
            path = "/cs128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 82:
            nazev = "Fun Radio Running SK";    // SK Fun Radio Running 
            host = "stream.funradio.sk";
            path = "/fun128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 83:
            nazev = "Radio Beta SK";    // SK Radio Beta
            host = "109.71.67.102";
            path = "/beta_live_high.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 84:
            nazev = "Radio Frontinus SK";    // SK Rádio Frontinus
            host = "stream.frontinus.sk";
            path = "/frontinus128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 85:
            nazev = "Radio SiTy SK";    // SK Rádio SiTy
            host = "icecast.radiosity.sk";
            path = "/hq.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 86:
            nazev = "Radio Plus Nitra 105.9 SK";    // SK Rádio Plus Nitra
            host = "stream.sepia.sk";
            path = "/plus128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 87:
            nazev = "Radio Viva SK";    // SK Rádio Viva
            host = "stream.sepia.sk";
            path = "/viva128.mp3";
            zanr="        POP";
            httpPort =8000;
            break;

         case 88:
            nazev = "RTVS Radio Devin SK";    // SK Rádio Devín
            host = "icecast.stv.livebox.sk";
            path = "/devin_128.mp3";
            zanr="       OLDIES";
            httpPort =80;
            break;

         case 89:
            nazev = "SKY Radio SK";    // SK SKY Rádio
            host = "stream.skyradio.sk";
            path = "/sky128";
            zanr="       RUZNE";
            httpPort =8000;
            break;

         case 90:
            nazev = "Radio Hana CZ";    // CZ Radio Hana
            host = "icecast8.play.cz";
            path = "/hana160.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 91:
            nazev = "AB Click and Country CZ";    // CZ AB Click and Country
            host = "62.168.118.229";
            path = "/clickandcountry.mp3";
            zanr="      COUNTRY";
            httpPort =8000;
            break;

         case 92:
            nazev = "AB Oldies Rock CZ";    // CZ AB Oldies Rock
            host = "mp3stream4.abradio.cz";
            path = "/oldiesrock128.mp3";
            zanr="       OLDIES";
            httpPort =80;
            break;

         case 93:
            nazev = "AB Rock Radio Prachen CZ";    // CZ AB Rock Radio Prácheň
            host = "ice.abradio.cz";
            path = "/prachen128.mp3";
            zanr="        ROCK";
            httpPort =80;
            break;

         case 94:
            nazev = "Cesky Impuls 981 AM";    // CZ Český Impuls 981 AM
            host = "icecast6.play.cz";
            path = "/cesky-impuls.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 95:
            nazev = "Cesky Rozhlas Brno";    // CZ ČRo Brno
            host = "icecast2.play.cz";
            path = "/crobrno128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 96:
            nazev = "Cesky Rozhlas Budejovice";    // CZ ČRo Budějovice
            host = "icecast2.play.cz";
            path = "/crocb128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 97:
            nazev = "Cesky Rozhlas Hradec Kralove";    // CZ ČRo Hradec Králové
            host = "icecast2.play.cz";
            path = "/crohk128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 98:
            nazev = "Cesky Rozhlas Karlovy Vary";    // CZ ČRo Karlovy Vary
            host = "icecast2.play.cz";
            path = "/crokv128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 99:
            nazev = "Cesky Rozhlas Liberec";    // CZ ČRo Liberec
            host = "icecast2.play.cz";
            path = "/croliberec128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 100:
            nazev = "Cesky Rozhlas Olomouc";    // CZ ČRo Olomouc
            host = "icecast2.play.cz";
            path = "/crool128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 101:
            nazev = "Cesky Rozhlas Ostrava";    // CZ ČRo Ostrava
            host = "icecast2.play.cz";
            path = "/croov128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 102:
            nazev = "Cesky Rozhlas Pardubice";    // CZ ČRo Pardubice
            host = "icecast2.play.cz";
            path = "/cropardubice128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 103:
            nazev = "Cesky Rozhlas Plzen";    // CZ ČRo Plzeň
            host = "icecast2.play.cz";
            path = "/croplzen128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 104:
            nazev = "Cesky Rozhlas Plus";    // CZ ČRo Plus
            host = "icecast1.play.cz";
            path = "/croplus128.mp3";
            zanr="    MLUVENE SLOVO";
            httpPort =80;
            break;

         case 105:
            nazev = "Cesky Rozhlas Regina";    // CZ ČRo Regina
            host = "icecast2.play.cz";
            path = "/croregina128.mp3";
            zanr="     REGIONALNI";
            httpPort =80;
            break;

         case 106:
            nazev = "Cesky Rozhlas Sever";    // CZ ČRo Sever
            host = "icecast2.play.cz";
            path = "/crosever128.mp3";
            zanr="     REGIONALNI";
            httpPort =80;
            break;

         case 107:
            nazev = "Cesky Rozhlas Stredocesky";    // CZ ČRo Stredocesky
            host = "icecast2.play.cz";
            path = "/croregion128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break; 

         case 108:
            nazev = "Cesky Rozhlas Vysocina";    // CZ ČRo Vysočina
            host = "icecast2.play.cz";
            path = "/crovysocina128.mp3";
            zanr="     REGIONALNI";
            httpPort =8000;
            break;

         case 109:
            nazev = "Evropa 2 Flashback CZ";    // CZ Evropa 2 Flashback
            host = "ice.actve.net";
            path = "/web-e2-flashback";
            zanr="        POP";
            httpPort =80;
            break;

         case 110:
            nazev = "Evropa 2 Hot CZ";    // CZ Evropa 2 Hot
            host = "ice.actve.net";
            path = "/web-e2-hot";
            zanr="        POP";
            httpPort =80;
            break;

         case 111:
            nazev = "Evropa 2 Movin CZ";    // CZ Evropa 2 Movin
            host = "ice.actve.net";
            path = "/web-e2-movin";
            zanr="        POP";
            httpPort =80;
            break;

         case 112:
            nazev = "Evropa 2 Top 40 CZ";    // CZ Evropa 2 Top 40
            host = "ice.actve.net";
            path = "/web-e2-top40";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 113:
            nazev = "Expres Radio 90.3 FM CZ";    // CZ Expres Radio 90.3 FM
            host = "icecast5.play.cz";
            path = "/expres128mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 114:
            nazev = "Fajn Fresh CZ";    // CZ Fajn Fresh
            host = "ice.abradio.cz";
            path = "/fajnfresh128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 115:
            nazev = "Fajn Hard CZ";    // CZ Fajn Hard
            host = "ice.abradio.cz";
            path = "/fajn128.mp3";
            zanr="        ROCK";
            httpPort =80;
            break;

         case 116:
            nazev = "Free Radio 107 FM CZ";    // CZ Free Rádio 107 FM
            host = "icecast8.play.cz";
            path = "/freeradio128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 117:
            nazev = "Frekvence 1 CZ";    // CZ Frekvence 1
            host = "icecast4.play.cz";
            path = "/frekvence1-128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 118:
            nazev = "Frekvence 1 Czech Hitz";    // CZ Frekvence 1 Czech Hitz
            host = "ice.actve.net";
            path = "/fm-frekvence1-128";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 119:
            nazev = "Frekvence 1 Diskoteka CZ";    // CZ Frekvence 1 Diskoteka
            host = "icecast4.play.cz";
            path = "/frekvence1-128.mp3";
            zanr="       DISCO";
            httpPort =80;
            break;

         case 120:
            nazev = "Frekvence 1 Romantika CZ";    // CZ Frekvence 1 Romantika
            host = "ice.actve.net";
            path = "/fm-frekvence1-128";
            zanr="       RELAX";
            httpPort =80;
            break;

         case 121:
            nazev = "Hitradio City 93,7 FM CZ";    // CZ Hitrádio City 93,7 FM
            host = "ice.abradio.cz";
            path = "/cityfm128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 122:
            nazev = "Hitradio City Devadesatka";    // CZ Hitrádio City Devadesátka
            host = "ice.abradio.cz";
            path = "/city90128.mp3";
            zanr="  DISKOTEKA 90 LET";
            httpPort =8000;
            break;

         case 123:
            nazev = "Hitradio City Osmdesatka";    // CZ Hitrádio City Osmdesátka
            host = "ice.abradio.cz";
            path = "/city80128.mp3";
            zanr="  DISKOTEKA 80 LET";
            httpPort =8000;
            break;

            case 124:
            nazev = "Hitradio City Zona Lazky";    // CZ Hitrádio City Zóna Lázky
            host = "ice.abradio.cz";
            path = "/cityzl128.mp3";
            zanr="       RUZNE";
            httpPort =8000;
            break;

            case 125:
            nazev = "Hitradio Crystal CZ";    // CZ Hitrádio Crystal
            host = "ice.abradio.cz";
            path = "/crystal128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 126:
            nazev = "Hitradio Dragon CZ";    // CZ Hitrádio Dragon
            host = "ice.abradio.cz";
            path = "/dragon128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 127:
            nazev = "Hitradio Faktor CZ";    // CZ Hitrádio Dragon
            host = "ice.abradio.cz";
            path = "/faktor128.mp3";
            zanr="       RUZNE";
            httpPort =8000;
            break;

         case 128:
            nazev = "Hitradio FM Plus CZ";    // CZ Hitrádio FM Plus
            host = "ice.abradio.cz";
            path = "/fmplus128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 129:
            nazev = "Hitradio Orion CZ";    // CZ Hitrádio Orion
            host = "ice.abradio.cz";
            path = "/orion128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 130:
            nazev = "Hitradio Orion Morava CZ";    // CZ Hitrádio Orion Morava
            host = "ice.abradio.cz";
            path = "/orionmorava128.mp3";
            zanr="       TOP 40";
            httpPort =80;
            break;

         case 131:
            nazev = "Kiss 98 FM CZ";    // CZ Kiss 98FM
            host = "icecast4.play.cz";
            path = "/kiss128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 132:
            nazev = "Kiss Delta CZ";    // CZ Kiss Delta
            host = "icecast1.play.cz";
            path = "/kissdelta192.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 133:
            nazev = "Kiss Publikum CZ";    // CZ Kiss Publikum
            host = "icecast5.play.cz";
            path = "/expres128mp3";
            zanr="       RUZNE";
            httpPort =8000;
            break;

         case 134:
            nazev = "Radio Cas Brnensko CZ";    // CZ Radio Čas Brněnsko
            host = "icecast7.play.cz";
            path = "/casbrno128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 135:
            nazev = "Radio Cas Olomoucko CZ";    // CZ Radio Čas Olomoucko
            host = "icecast7.play.cz";
            path = "/casradioolomouc64.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 136:
            nazev = "Radio Cas Rock CZ";    // CZ Radio Čas Rock
            host = "icecast7.play.cz";
            path = "/casrock128.mp3";
            zanr="        ROCK";
            httpPort =80;
            break;

         case 137:
            nazev = "Radio Helax CZ";    // CZ Radio Helax
            host = "ice.abradio.cz";
            path = "/helax128.mp3";
            zanr="        POP";
            httpPort =80;
            break;

         case 138:
            nazev = "Radio Impuls CZ";    // CZ Radio Impuls
            host = "icecast5.play.cz";
            path = "/impuls128.mp3";
            zanr="       RUZNE";
            httpPort =80;
            break;

         case 139:
            nazev = "Radio Rubi"; 
            host = "icecast8.play.cz";       // Radio Rubi
            path = "/radiorubi128.mp3";
            zanr="       TOP 40";
            httpPort = 80;
            break;  

         case 140:
            nazev = "Radio Samson CZ"; 
            host = "icecast2.play.cz";       // CZ Radio Samson
            path = "/samsonfm128aac";
            zanr="       TOP 40";
            httpPort = 8000;
            break; 

         case 141:
             nazev = "Radio Spin CZ"; 
             host = "icecast1.play.cz";       // CZ Radio Spin
             path = "/spin128aac";
             zanr="      HIP HOP";
             httpPort = 8000;
             break;

          case 142:
             nazev = "Radio Zlin CZ"; 
             host = "212.111.2.151";       // CZ Radio Zlin
             path = "/radiozlin_128.mp3";
             zanr="       TOP 40";
             httpPort = 8000;
             break;

          case 143:
             nazev = "Route 66 CZ"; 
             host = "ice3.abradio.cz";       // CZ Route 66
             path = "/route128.mp3";
             zanr="       COUNTRY";
             httpPort = 80;
             break;

          case 144:
             nazev = "SeeJay CZ"; 
             host = "mp3stream.abradio.cz";       // CZ SeeJay
             path = "/seejay128.mp3";
             zanr="        DANCE";
             httpPort = 8000;
             break;

          case 145:
             nazev = "Cas Radio Ostravsko"; 
             host = "icecast1.play.cz";       // CZ Čas rádio Ostravsko
             path = "/casradio32aac";
             zanr="       RUZNE";
             httpPort = 8000;
             break;

         case 146:
            nazev = "Cas Radio Zlinsko"; 
            host = "icecast1.play.cz";       // CZ Čas rádio Zlínsko
            path = "/casradiozlin32aac";
            zanr="       RUZNE";
            httpPort = 80;
            break;

         case 147:
            nazev = "Signal Radio CZ"; 
            host = "icecast1.play.cz";       // CZ Signál rádio 
            path = "/signal192.mp3";
            zanr="       RUZNE";
            httpPort = 80;
            break;

         case 148:
            nazev = "Signal Radio CZ"; 
            host = "radio.ipip.cz";       // CZ Signál rádio 
            path = "/";
            zanr="       RUZNE";
            httpPort = 7996;
            break;


         case 149:
            nazev = "Color CZ"; 
            host = "sc.ipip.cz";       // CZ Color rádio 
            path = "/";
            zanr="       RUZNE";
            httpPort = 8206;
            break;

         case 150:
            nazev = "Antenne Bayern - 90er Hits"; 
            host = "mp3channels.webradio.antenne.de";       // Antenne Bayern - 90er Hits 
            path = "/90er-hits";
            zanr="  DISKOTEKA 90 LET";
            httpPort = 80;
            break;
    }

    //--------------------------------------------------------------------------------------------------------
                                                        
    if(!client.connected() || pamet_ID_stanice!=ID_stanice){    
    
      if(client.connect(host, httpPort)){                                 // Adresa serveru se streamem - ve smyčce
       client.print(String("GET ") + path + " HTTP/1.1\r\n" +
                  "Host: " + host + "\r\n" + 
                  "Connection: close\r\n\r\n");
              pamet_ID_stanice=ID_stanice;

              lcd.clear();                                  // Smaz znaky na LCD
              lcd.setCursor(4,0);                           // Nastav kurzor na 5 znak prvního řádku
              lcd.print("Predvolba: ");                     // Zobraz na této pozici text Predvolba
              lcd.setCursor(15,0);                          // Nastav kurzor na 16 znak prvního řádku
              lcd.print(ID_stanice);                        // Vypiš na této pozici číslo aktuální předvolby stanice
              lcd.setCursor(0,2);                           // Nastav kurzor na 1 znak třetího řádku
              lcd.print("--------------------");            // Zobraz na této pozici text -------------------- 
              lcd.setCursor(0,3);                           // Nastav kurzor na 1 znak čtvrtého řádku
              lcd.print(zanr);                              // Zobraz na tomto řádku žánr stanice
         
 
      }
     }
  
    if(client.available() > 0){                                          // Pokud je server dostupný, tak :
      uint8_t bytesread = client.read(mp3buff,32);                       // ulož přijatá data do bufferu
    MP3player.playChunk(mp3buff,bytesread);                              // a přehraj na VS1053B Shield
}  
   if (Prodleva >= 300){
       
  Posuv();                        // Zavolej funkci posuv znaků na řádku
}
}

//-------------------------------------------------------------------------------------------------------------------------------

String Scroll_LCD_Left(String StrDisplay){
  String result;
  String StrProcess = "                   " + StrDisplay + "                   ";     // Mezera = počet znaků na řádku
  result = StrProcess.substring(Li,Lii);
  Li++;
  Lii++;
  if (Li>StrProcess.length()){
    Li=20;
    Lii=0;
  }
  return result;
} 


void Posuv(){
  Prodleva=0;
  Delka_textu = nazev.length();
                                   
    lcd.setCursor(0, 1);                // Nastav kurzor na 1 znak druhého řádku                                         
    lcd.print(Scroll_LCD_Left(nazev));   

}

// Konec
// David Kohout 2 / 2020


